@@ -10,7 +10,7 @@ STOCK_CODE_PATH = os.path.join(os.path.dirname(__file__), "stock_codes.conf")
 def update_stock_codes():
     """获取所有股票 ID 到 all_stock_code 目录下"""
     response = requests.get("http://www.shdjt.com/js/lib/astock.js")
-    stock_codes = re.findall(r"~(\d+)`", response.text)
+    stock_codes = re.findall(r"~([a-z0-9]*)`", response.text)
     with open(STOCK_CODE_PATH, "w") as f:
         f.write(json.dumps(dict(stock=stock_codes)))
     return stock_codes
@@ -33,9 +33,9 @@ def get_stock_type(stock_code):
     :param stock_code:股票ID, 若以 'sz', 'sh' 开头直接返回对应类型，否则使用内置规则判断
     :return 'sh' or 'sz'"""
     assert type(stock_code) is str, "stock code need str type"
-    sh_head = ("50", "51", "60", "90", "110", "113",
+    sh_head = ("50", "51", "60", "90", "110", "113", "118",
                "132", "204", "5", "6", "9", "7")
-    if stock_code.startswith(("sh", "sz")):
+    if stock_code.startswith(("sh", "sz", "zz")):
         return stock_code[:2]
     else:
         return "sh" if stock_code.startswith(sh_head) else "sz"
